@@ -77,6 +77,15 @@ module VCR
     end
     alias ignore_host ignore_hosts
 
+    # Specifies host(s) that VCR should stop ignoring.
+    #
+    # @param hosts [Array<String>] List of hosts to unignore
+    # @see #ignore_hosts
+    def unignore_hosts(*hosts)
+      VCR.request_ignorer.unignore_hosts(*hosts)
+    end
+    alias unignore_host unignore_hosts
+
     # Sets whether or not VCR should ignore localhost requests.
     #
     # @param value [Boolean] the value to set
@@ -222,7 +231,7 @@ module VCR
 
       before_playback(tag) do |interaction|
         orig_text = call_block(block, interaction)
-        log "before_playback: replacing #{placeholder.inspect} with #{orig_text.inspect}"
+        log "before_playback: replacing #{orig_text.inspect} with #{placeholder.inspect}"
         interaction.filter!(placeholder, orig_text)
       end
     end
@@ -483,6 +492,7 @@ module VCR
       @rspec_metadata_configured = false
       @default_cassette_options = {
         :record            => :once,
+        :record_on_error   => true,
         :match_requests_on => RequestMatcherRegistry::DEFAULT_MATCHERS,
         :allow_unused_http_interactions => true,
         :serialize_with    => :yaml,
@@ -550,6 +560,10 @@ module VCR
     end
 
     def register_built_in_hooks
+      before_playback(:recompress_response) do |interaction|
+        interaction.response.recompress if interaction.response.vcr_decompressed?
+      end
+
       before_playback(:update_content_length_header) do |interaction|
         interaction.response.update_content_length_header
       end
@@ -571,4 +585,3 @@ module VCR
     define_hook :after_library_hooks_loaded
   end
 end
-
